@@ -14,7 +14,7 @@
 // Project version
 #define XPYT_VERSION_MAJOR 0
 #define XPYT_VERSION_MINOR 9
-#define XPYT_VERSION_PATCH 2
+#define XPYT_VERSION_PATCH 3
 
 // Composing the version string from major, minor and patch
 #define XPYT_CONCATENATE(A, B) XPYT_CONCATENATE_IMPL(A, B)
@@ -36,4 +36,9 @@
     #define XEUS_PYTHON_API
 #endif
 
+#ifdef _MSC_VER
+    #define XPYT_FORCE_PYBIND11_EXPORT
+#else
+    #define XPYT_FORCE_PYBIND11_EXPORT __attribute__ ((visibility ("default")))
+#endif
 #endif
